@@ -1,9 +1,13 @@
 context("Various helper functions")
 
+test_that("Functions not exported can be found", {
+    expect_true(.internalFunction())
+})
+
 public({
     test_that("If a function is not exported, the public test context errors", {
-        expect_error(caching(),
-            'could not find function "caching"')
+        expect_error(.internalFunction(),
+            'could not find function ".internalFunction"')
     })
 })
 
